autowisp.source_finder module — AutoWISP documentation

# autowisp.source_finder module

## Class Inheritance Diagram

Uniform interface for source extractoin using several methods.

class autowisp.source_finder.SourceFinder(*, tool='hatphot', brightness_threshold=10, filter_sources='True', max_sources=0, allow_overwrite=False, allow_dir_creation=False, always_return_sources=False)

  Bases: `object`

  Find sources in an image of the night sky and repor properties.

  __call__(fits_fname, source_fname=None, **configuration)

    Extract the sources from the given frame and save or return them.

    Parameters:

      - fits_fname (str) – The filename of the fits file to extract sources from. Can be packed or unpacked.

      - source_fname (str or None) – If None, the extract sources are returned as numpy. field array. Otherwise, this specifies a file to save the source extractor output.

    Returns:

      The extracted source from the image, if source_fname was None.

    Return type:

      field array or None

  __init__(*, tool='hatphot', brightness_threshold=10, filter_sources='True', max_sources=0, allow_overwrite=False, allow_dir_creation=False, always_return_sources=False)

    Prepare to use the specified tool and define faint limit.

  _add_saturation_flags(fits_fname, source_list)

    Add array of how many pixels near source are saturated.

  static _create_mock_source_list(fits_fname, configuration)

    Create a source list with randomly generated properties.